Data

Trait Data 

pub trait Data {
    // Required methods
    fn at(&self, row: usize, cell: usize) -> String;
    fn rows(&self) -> usize;
    fn columns(&self) -> usize;
}
Data is the interface that wraps the basic methods of a table model.

Required Methods

fn at(&self, row: usize, cell: usize) -> String

At returns the contents of the cell at the given index.

fn rows(&self) -> usize

Rows returns the number of rows in the table.

fn columns(&self) -> usize

Columns returns the number of columns in the table.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors